function [function_spec] = Make_function_spec()

    % Copyright (c) 2015-2023 Martin Neuenhofen. 


    %% define integral functions of your usecase
    % see below and change formulas for a,f,g.
    
    % pre-defined sample problems
    %PROBLEM = 'ConvDiff';
    PROBLEM = 'Poisson';
    
    
    % define your inner integral functions for a, f and g of bilinear 
    % and linear forms.
    % phiTes    : test function
    % phiAns    : ansatz function
    % Dphi      : gradients
    % x         : point in domain
    % h         : diameter of finite element (necessary for some stabilization techniques)
    %
    % a         : inner function of bilinear form b:    b(u,v)  = integral_Omega a(x,u,v,Du,Dv) dx
    % f,g       : inner functions of linear form l:     l(v)    = integral_Omega f(x,v,Dv) dx + integral_NeumannBound g(x,v,Dv) dx
    %
    % NOTICE:
    %   This inline definition makes the stiffness matrix assembling much
    % slower. Consider replacing the inline call in Assembler_4.m by direct
    % coding.
    
    switch PROBLEM
        % pre-defined sample problems
        case 'ConvDiff'
            % Convection-Diffusion, SDFEM-Stabilization.
            a   = '0.01 * transpose(DphiTes)*DphiAns + (phiTes+h/2*[0.6,0.8]*DphiTes(1:2,1)) * 2*[0.6,0.8]*DphiAns(1:2,1)';
            f   = 'phiTes * 1';
            g   = 'phiTes * 1';
        % end case

        case 'Poisson'
            % Standard-example
            a   = 'transpose(DphiTes)*DphiAns';
            f   = 'phiTes * 0';
            g   = 'phiTes * 1';
        % end case
    end
    
    

    %% translate functions
    a_func                              = inline(a,'phiTes','DphiTes','phiAns','DphiAns','x','h');
    f_func                              = inline(f,'phiTes','DphiTes','x','h');
    g_func                              = inline(g,'phiTes','DphiTes','x','h');


    %% Ausgaben einpacken
    function_spec.deg_Ans   = 1;
    function_spec.deg_Tes   = 1;
    
    function_spec.a         = a_func;
    function_spec.f         = f_func;
    function_spec.g         = g_func;
    
end