function [Mesh,A,b] = UseCase()

    %% Description
    % This is an example of how to use Simple FEM.
    % Follow these steps:
    %   1) Define (stabilized) continuous variational problem
    %   2) Define domain and boundaries
    %   3) Assemble the mesh
    %   4) Extend number of nodes in case of higher order elements
    %   5) Map boundaries to mesh nodes
    %   6) Assemble system
    %   7) Solve System
    %   8) Visualize solution
    %
    % NOTICE:
    %   You can also do steps 1 to 5 indepentend of the others, for example to
    %   construct different block matrices on the same mesh.

   	disp('Define Variational problem by integral functions')
    [function_spec] = Make_function_spec();
    
    
    figure;
    disp('Define Domain and boundaries')
    [bound_funcs] = Make_bound_funcs();
    
    
    disp('Make triangulation with modified distmesh ')
    [Mesh]=distmeshnd(bound_funcs);
    %   overloaded distmeshnd variant of Per-Olof Persson and Gilbert Strang.
    
    
    figure; deg = 2;
    disp('add nodes for nodal basis functions of higher order')
    [Mesh] = Mesh_Enricher(Mesh,deg);
    
    
    disp('map boundary conditions to mesh nodes')
    [Mesh] = getBoundary(bound_funcs,Mesh);
    
    
    disp('Assemble equation system')
    [A,b] = Assembler_4(Mesh,function_spec);
    
    
    disp('solve')
    x = A\b;
    
    
    figure;
    disp('Visualize solution as scalar field')
    [Mesh] = Solution_Plotter_Scalar(x,Mesh);
    

end